==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterLoadBalancerProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Profile of the managed cluster load balancer.
 * @property allocatedOutboundPorts The desired number of allocated SNAT ports per VM. Allowed values are in the range of 0 to 64000 (inclusive). The default value is 0 which results in Azure dynamically allocating ports.
 * @property effectiveOutboundIPs The effective outbound IP resources of the cluster load balancer.
 * @property enableMultipleStandardLoadBalancers Enable multiple standard load balancers per AKS cluster or not.
 * @property idleTimeoutInMinutes Desired outbound flow idle timeout in minutes. Allowed values are in the range of 4 to 120 (inclusive). The default value is 30 minutes.
 * @property managedOutboundIPs Desired managed outbound IPs for the cluster load balancer.
 * @property outboundIPPrefixes Desired outbound IP Prefix resources for the cluster load balancer.
 * @property outboundIPs Desired outbound IP resources for the cluster load balancer.
 */
public data class ManagedClusterLoadBalancerProfileArgs(
    public val allocatedOutboundPorts: Output<Int>? = null,
    public val effectiveOutboundIPs: Output<List<ResourceReferenceArgs>>? = null,
    public val enableMultipleStandardLoadBalancers: Output<Boolean>? = null,
    public val idleTimeoutInMinutes: Output<Int>? = null,
    public val managedOutboundIPs: Output<ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs>? =
        null,
    public val outboundIPPrefixes: Output<ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs>? =
        null,
    public val outboundIPs: Output<ManagedClusterLoadBalancerProfileOutboundIPsArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs.builder()
            .allocatedOutboundPorts(allocatedOutboundPorts?.applyValue({ args0 -> args0 }))
            .effectiveOutboundIPs(
                effectiveOutboundIPs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enableMultipleStandardLoadBalancers(
                enableMultipleStandardLoadBalancers?.applyValue({ args0 ->
                    args0
                }),
            )
            .idleTimeoutInMinutes(idleTimeoutInMinutes?.applyValue({ args0 -> args0 }))
            .managedOutboundIPs(
                managedOutboundIPs?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .outboundIPPrefixes(
                outboundIPPrefixes?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .outboundIPs(outboundIPs?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagedClusterLoadBalancerProfileArgs].
 */
@PulumiTagMarker
public class ManagedClusterLoadBalancerProfileArgsBuilder internal constructor() {
    private var allocatedOutboundPorts: Output<Int>? = null

    private var effectiveOutboundIPs: Output<List<ResourceReferenceArgs>>? = null

    private var enableMultipleStandardLoadBalancers: Output<Boolean>? = null

    private var idleTimeoutInMinutes: Output<Int>? = null

    private var managedOutboundIPs: Output<ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs>? =
        null

    private var outboundIPPrefixes: Output<ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs>? =
        null

    private var outboundIPs: Output<ManagedClusterLoadBalancerProfileOutboundIPsArgs>? = null

    /**
     * @param value The desired number of allocated SNAT ports per VM. Allowed values are in the range of 0 to 64000 (inclusive). The default value is 0 which results in Azure dynamically allocating ports.
     */
    @JvmName("bjhxpjgvlcuesdev")
    public suspend fun allocatedOutboundPorts(`value`: Output<Int>) {
        this.allocatedOutboundPorts = value
    }

    /**
     * @param value The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("rjxhfukkhntsnoto")
    public suspend fun effectiveOutboundIPs(`value`: Output<List<ResourceReferenceArgs>>) {
        this.effectiveOutboundIPs = value
    }

    @JvmName("hxebacnsgfheagey")
    public suspend fun effectiveOutboundIPs(vararg values: Output<ResourceReferenceArgs>) {
        this.effectiveOutboundIPs = Output.all(values.asList())
    }

    /**
     * @param values The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("ffvajpjdonvguiuw")
    public suspend fun effectiveOutboundIPs(values: List<Output<ResourceReferenceArgs>>) {
        this.effectiveOutboundIPs = Output.all(values)
    }

    /**
     * @param value Enable multiple standard load balancers per AKS cluster or not.
     */
    @JvmName("hgbahlpwsorgotdg")
    public suspend fun enableMultipleStandardLoadBalancers(`value`: Output<Boolean>) {
        this.enableMultipleStandardLoadBalancers = value
    }

    /**
     * @param value Desired outbound flow idle timeout in minutes. Allowed values are in the range of 4 to 120 (inclusive). The default value is 30 minutes.
     */
    @JvmName("pwruvkmlvaxvptxj")
    public suspend fun idleTimeoutInMinutes(`value`: Output<Int>) {
        this.idleTimeoutInMinutes = value
    }

    /**
     * @param value Desired managed outbound IPs for the cluster load balancer.
     */
    @JvmName("siufamygycaykjwj")
    public suspend
    fun managedOutboundIPs(`value`: Output<ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs>) {
        this.managedOutboundIPs = value
    }

    /**
     * @param value Desired outbound IP Prefix resources for the cluster load balancer.
     */
    @JvmName("jqqafwiefxoyghyf")
    public suspend
    fun outboundIPPrefixes(`value`: Output<ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs>) {
        this.outboundIPPrefixes = value
    }

    /**
     * @param value Desired outbound IP resources for the cluster load balancer.
     */
    @JvmName("gftfmrssegecevrs")
    public suspend
    fun outboundIPs(`value`: Output<ManagedClusterLoadBalancerProfileOutboundIPsArgs>) {
        this.outboundIPs = value
    }

    /**
     * @param value The desired number of allocated SNAT ports per VM. Allowed values are in the range of 0 to 64000 (inclusive). The default value is 0 which results in Azure dynamically allocating ports.
     */
    @JvmName("xhkhehqvpcglxdxa")
    public suspend fun allocatedOutboundPorts(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allocatedOutboundPorts = mapped
    }

    /**
     * @param value The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("inviyifbvkojpmpw")
    public suspend fun effectiveOutboundIPs(`value`: List<ResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param argument The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("cxetqmwvvxpqbgyv")
    public suspend
    fun effectiveOutboundIPs(argument: List<suspend ResourceReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param argument The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("upawpxyfpknkeqxd")
    public suspend fun effectiveOutboundIPs(
        vararg
        argument: suspend ResourceReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param argument The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("engchrwqsuhqkmtr")
    public suspend
    fun effectiveOutboundIPs(argument: suspend ResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param values The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("tkdyyiaotdysuyph")
    public suspend fun effectiveOutboundIPs(vararg values: ResourceReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param value Enable multiple standard load balancers per AKS cluster or not.
     */
    @JvmName("jxmtvebheossdico")
    public suspend fun enableMultipleStandardLoadBalancers(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMultipleStandardLoadBalancers = mapped
    }

    /**
     * @param value Desired outbound flow idle timeout in minutes. Allowed values are in the range of 4 to 120 (inclusive). The default value is 30 minutes.
     */
    @JvmName("acwjumrbgbakmxkg")
    public suspend fun idleTimeoutInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.idleTimeoutInMinutes = mapped
    }

    /**
     * @param value Desired managed outbound IPs for the cluster load balancer.
     */
    @JvmName("otkynjmunbupnhuc")
    public suspend
    fun managedOutboundIPs(`value`: ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedOutboundIPs = mapped
    }

    /**
     * @param argument Desired managed outbound IPs for the cluster load balancer.
     */
    @JvmName("ndjciegkgnhdbkuh")
    public suspend
    fun managedOutboundIPs(argument: suspend ManagedClusterLoadBalancerProfileManagedOutboundIPsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterLoadBalancerProfileManagedOutboundIPsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.managedOutboundIPs = mapped
    }

    /**
     * @param value Desired outbound IP Prefix resources for the cluster load balancer.
     */
    @JvmName("baquccjcojimtwvb")
    public suspend
    fun outboundIPPrefixes(`value`: ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outboundIPPrefixes = mapped
    }

    /**
     * @param argument Desired outbound IP Prefix resources for the cluster load balancer.
     */
    @JvmName("pbvucjdqlwgalguw")
    public suspend
    fun outboundIPPrefixes(argument: suspend ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.outboundIPPrefixes = mapped
    }

    /**
     * @param value Desired outbound IP resources for the cluster load balancer.
     */
    @JvmName("hwbmitocqqupbsqo")
    public suspend fun outboundIPs(`value`: ManagedClusterLoadBalancerProfileOutboundIPsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outboundIPs = mapped
    }

    /**
     * @param argument Desired outbound IP resources for the cluster load balancer.
     */
    @JvmName("mnpqialyngafatxg")
    public suspend
    fun outboundIPs(argument: suspend ManagedClusterLoadBalancerProfileOutboundIPsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterLoadBalancerProfileOutboundIPsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.outboundIPs = mapped
    }

    internal fun build(): ManagedClusterLoadBalancerProfileArgs =
        ManagedClusterLoadBalancerProfileArgs(
            allocatedOutboundPorts = allocatedOutboundPorts,
            effectiveOutboundIPs = effectiveOutboundIPs,
            enableMultipleStandardLoadBalancers = enableMultipleStandardLoadBalancers,
            idleTimeoutInMinutes = idleTimeoutInMinutes,
            managedOutboundIPs = managedOutboundIPs,
            outboundIPPrefixes = outboundIPPrefixes,
            outboundIPs = outboundIPs,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterLoadBalancerProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Profile of the managed cluster load balancer.
 * @property allocatedOutboundPorts The desired number of allocated SNAT ports per VM. Allowed values are in the range of 0 to 64000 (inclusive). The default value is 0 which results in Azure dynamically allocating ports.
 * @property effectiveOutboundIPs The effective outbound IP resources of the cluster load balancer.
 * @property enableMultipleStandardLoadBalancers Enable multiple standard load balancers per AKS cluster or not.
 * @property idleTimeoutInMinutes Desired outbound flow idle timeout in minutes. Allowed values are in the range of 4 to 120 (inclusive). The default value is 30 minutes.
 * @property managedOutboundIPs Desired managed outbound IPs for the cluster load balancer.
 * @property outboundIPPrefixes Desired outbound IP Prefix resources for the cluster load balancer.
 * @property outboundIPs Desired outbound IP resources for the cluster load balancer.
 */
public data class ManagedClusterLoadBalancerProfileArgs(
    public val allocatedOutboundPorts: Output<Int>? = null,
    public val effectiveOutboundIPs: Output<List<ResourceReferenceArgs>>? = null,
    public val enableMultipleStandardLoadBalancers: Output<Boolean>? = null,
    public val idleTimeoutInMinutes: Output<Int>? = null,
    public val managedOutboundIPs: Output<ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs>? =
        null,
    public val outboundIPPrefixes: Output<ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs>? =
        null,
    public val outboundIPs: Output<ManagedClusterLoadBalancerProfileOutboundIPsArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterLoadBalancerProfileArgs.builder()
            .allocatedOutboundPorts(allocatedOutboundPorts?.applyValue({ args0 -> args0 }))
            .effectiveOutboundIPs(
                effectiveOutboundIPs?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enableMultipleStandardLoadBalancers(
                enableMultipleStandardLoadBalancers?.applyValue({ args0 ->
                    args0
                }),
            )
            .idleTimeoutInMinutes(idleTimeoutInMinutes?.applyValue({ args0 -> args0 }))
            .managedOutboundIPs(
                managedOutboundIPs?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .outboundIPPrefixes(
                outboundIPPrefixes?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .outboundIPs(outboundIPs?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagedClusterLoadBalancerProfileArgs].
 */
@PulumiTagMarker
public class ManagedClusterLoadBalancerProfileArgsBuilder internal constructor() {
    private var allocatedOutboundPorts: Output<Int>? = null

    private var effectiveOutboundIPs: Output<List<ResourceReferenceArgs>>? = null

    private var enableMultipleStandardLoadBalancers: Output<Boolean>? = null

    private var idleTimeoutInMinutes: Output<Int>? = null

    private var managedOutboundIPs: Output<ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs>? =
        null

    private var outboundIPPrefixes: Output<ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs>? =
        null

    private var outboundIPs: Output<ManagedClusterLoadBalancerProfileOutboundIPsArgs>? = null

    /**
     * @param value The desired number of allocated SNAT ports per VM. Allowed values are in the range of 0 to 64000 (inclusive). The default value is 0 which results in Azure dynamically allocating ports.
     */
    @JvmName("yxunbgohbsubajij")
    public suspend fun allocatedOutboundPorts(`value`: Output<Int>) {
        this.allocatedOutboundPorts = value
    }

    /**
     * @param value The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("vtjyqbgdqbpbobdt")
    public suspend fun effectiveOutboundIPs(`value`: Output<List<ResourceReferenceArgs>>) {
        this.effectiveOutboundIPs = value
    }

    @JvmName("wycsuinidhtloxdi")
    public suspend fun effectiveOutboundIPs(vararg values: Output<ResourceReferenceArgs>) {
        this.effectiveOutboundIPs = Output.all(values.asList())
    }

    /**
     * @param values The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("qfqtopukoqpkqfji")
    public suspend fun effectiveOutboundIPs(values: List<Output<ResourceReferenceArgs>>) {
        this.effectiveOutboundIPs = Output.all(values)
    }

    /**
     * @param value Enable multiple standard load balancers per AKS cluster or not.
     */
    @JvmName("beydhkvtxcfajvtb")
    public suspend fun enableMultipleStandardLoadBalancers(`value`: Output<Boolean>) {
        this.enableMultipleStandardLoadBalancers = value
    }

    /**
     * @param value Desired outbound flow idle timeout in minutes. Allowed values are in the range of 4 to 120 (inclusive). The default value is 30 minutes.
     */
    @JvmName("chykpigkgoqrxikl")
    public suspend fun idleTimeoutInMinutes(`value`: Output<Int>) {
        this.idleTimeoutInMinutes = value
    }

    /**
     * @param value Desired managed outbound IPs for the cluster load balancer.
     */
    @JvmName("hnvwvkyilymumlpw")
    public suspend
    fun managedOutboundIPs(`value`: Output<ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs>) {
        this.managedOutboundIPs = value
    }

    /**
     * @param value Desired outbound IP Prefix resources for the cluster load balancer.
     */
    @JvmName("blputthqwwcvittp")
    public suspend
    fun outboundIPPrefixes(`value`: Output<ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs>) {
        this.outboundIPPrefixes = value
    }

    /**
     * @param value Desired outbound IP resources for the cluster load balancer.
     */
    @JvmName("agylrfebrsabyyfo")
    public suspend
    fun outboundIPs(`value`: Output<ManagedClusterLoadBalancerProfileOutboundIPsArgs>) {
        this.outboundIPs = value
    }

    /**
     * @param value The desired number of allocated SNAT ports per VM. Allowed values are in the range of 0 to 64000 (inclusive). The default value is 0 which results in Azure dynamically allocating ports.
     */
    @JvmName("yvohjgwejappiwbc")
    public suspend fun allocatedOutboundPorts(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allocatedOutboundPorts = mapped
    }

    /**
     * @param value The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("jdnlsthruuoeegnh")
    public suspend fun effectiveOutboundIPs(`value`: List<ResourceReferenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param argument The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("afiimcupvwlvksbw")
    public suspend
    fun effectiveOutboundIPs(argument: List<suspend ResourceReferenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param argument The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("detoturyjgsytqey")
    public suspend fun effectiveOutboundIPs(
        vararg
        argument: suspend ResourceReferenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceReferenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param argument The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("lcpvwxwpiccahocl")
    public suspend
    fun effectiveOutboundIPs(argument: suspend ResourceReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ResourceReferenceArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param values The effective outbound IP resources of the cluster load balancer.
     */
    @JvmName("lfjyjsddhqovnypg")
    public suspend fun effectiveOutboundIPs(vararg values: ResourceReferenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.effectiveOutboundIPs = mapped
    }

    /**
     * @param value Enable multiple standard load balancers per AKS cluster or not.
     */
    @JvmName("wqyqmaihrbxekqfg")
    public suspend fun enableMultipleStandardLoadBalancers(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableMultipleStandardLoadBalancers = mapped
    }

    /**
     * @param value Desired outbound flow idle timeout in minutes. Allowed values are in the range of 4 to 120 (inclusive). The default value is 30 minutes.
     */
    @JvmName("bbxrecxnfcgqfuhc")
    public suspend fun idleTimeoutInMinutes(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.idleTimeoutInMinutes = mapped
    }

    /**
     * @param value Desired managed outbound IPs for the cluster load balancer.
     */
    @JvmName("eansgugkuiibcsab")
    public suspend
    fun managedOutboundIPs(`value`: ManagedClusterLoadBalancerProfileManagedOutboundIPsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.managedOutboundIPs = mapped
    }

    /**
     * @param argument Desired managed outbound IPs for the cluster load balancer.
     */
    @JvmName("yrvujsymhglqotoh")
    public suspend
    fun managedOutboundIPs(argument: suspend ManagedClusterLoadBalancerProfileManagedOutboundIPsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterLoadBalancerProfileManagedOutboundIPsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.managedOutboundIPs = mapped
    }

    /**
     * @param value Desired outbound IP Prefix resources for the cluster load balancer.
     */
    @JvmName("aefpndxdsppdglqa")
    public suspend
    fun outboundIPPrefixes(`value`: ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outboundIPPrefixes = mapped
    }

    /**
     * @param argument Desired outbound IP Prefix resources for the cluster load balancer.
     */
    @JvmName("rwutndwbeqkpntte")
    public suspend
    fun outboundIPPrefixes(argument: suspend ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterLoadBalancerProfileOutboundIPPrefixesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.outboundIPPrefixes = mapped
    }

    /**
     * @param value Desired outbound IP resources for the cluster load balancer.
     */
    @JvmName("okjhougjxyxhgmnh")
    public suspend fun outboundIPs(`value`: ManagedClusterLoadBalancerProfileOutboundIPsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.outboundIPs = mapped
    }

    /**
     * @param argument Desired outbound IP resources for the cluster load balancer.
     */
    @JvmName("pjjvgidqjkgmjnbw")
    public suspend
    fun outboundIPs(argument: suspend ManagedClusterLoadBalancerProfileOutboundIPsArgsBuilder.() -> Unit) {
        val toBeMapped = ManagedClusterLoadBalancerProfileOutboundIPsArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.outboundIPs = mapped
    }

    internal fun build(): ManagedClusterLoadBalancerProfileArgs =
        ManagedClusterLoadBalancerProfileArgs(
            allocatedOutboundPorts = allocatedOutboundPorts,
            effectiveOutboundIPs = effectiveOutboundIPs,
            enableMultipleStandardLoadBalancers = enableMultipleStandardLoadBalancers,
            idleTimeoutInMinutes = idleTimeoutInMinutes,
            managedOutboundIPs = managedOutboundIPs,
            outboundIPPrefixes = outboundIPPrefixes,
            outboundIPs = outboundIPs,
        )
}
